@@ -1,44 +1,3 @@
-#' Create Clean Reported Cases
-#' @description `r lifecycle::badge("deprecated")`
-#' Filters leading zeros, completes dates, and applies an optional threshold at
-#' which point 0 cases are replaced with a user supplied value (defaults to
-#' `NA`).
-#'
-#' @param filter_leading_zeros Logical, defaults to TRUE. Should zeros at the
-#' start of the time series be filtered out.
-#'
-#' @param zero_threshold `r lifecycle::badge("experimental")` Numeric defaults
-#' to Inf. Indicates if detected zero cases are meaningful by using a threshold
-#' number of cases based on the 7-day average. If the average is above this
-#' threshold then the zero is replaced using `fill`.
-#'
-#' @param fill Deprecated; zero dates with  7-day averages above the
-#'   `zero_threshold` will be skipped in model fitting.
-#' @param add_breakpoints Logical, defaults to TRUE. Should a breakpoint column
-#' be added to the data frame if it does not exist.
-#'
-#' @inheritParams estimate_infections
-#' @return A cleaned data frame of reported cases
-#' @keywords internal
-#' @examples
-#' \dontrun{
-#' create_clean_reported_cases(example_confirmed, 7)
-#' }
-create_clean_reported_cases <- function(data,
-                                        filter_leading_zeros = TRUE,
-                                        zero_threshold = Inf,
-                                        fill = NA_integer_,
-                                        add_breakpoints = TRUE) {
-  if (add_breakpoints) {
-    data <- add_breakpoints(data)
-  }
-  if (filter_leading_zeros) {
-    data <- filter_leading_zeros(data)
-  }
-  data <- apply_zero_threshold(data, zero_threshold)
-  return(data[])
-}
-
 #' Create Delay Shifted Cases
 #'
 #' @description `r lifecycle::badge("stable")`
@@ -78,8 +37,7 @@ create_clean_reported_cases <- function(data,
 #' horizon <- 7
 #' smoothing_window <- 14
 #' ## add NAs for horizon
-#' cases <- create_clean_reported_cases(example_confirmed[1:30])
-#' cases <- add_horizon(cases, horizon)
+#' cases <- add_horizon(example_confirmed[1:30], horizon)
 #' ## add zeroes initially
 #' cases <- data.table::rbindlist(list(
 #'   data.table::data.table(
@@ -178,6 +136,7 @@ create_future_rt <- function(future = c("latest", "project", "estimate"),
 #' @description `r lifecycle::badge("stable")`
 #' Takes the output from [rt_opts()] and converts it into a list understood by
 #' stan.
+#'
 #' @param rt A list of options as generated by [rt_opts()] defining Rt
 #' estimation. Defaults to [rt_opts()]. To generate new infections using
 #' the non-mechanistic model instead of the renewal equation model, use
