@@ -231,24 +231,3 @@ test_that("epinow works as expected when forecast_opts horizon is 0 with default
   expect_true(out$estimates$args$horizon == 0)
 })
 
-test_that("horizon overrides forecast$horizon if both specified", {
-  horizon <- 14
-  suppressMessages(suppressWarnings(
-    out <- epinow(
-      data = reported_cases,
-      generation_time = gt_opts(example_generation_time),
-      delays = delay_opts(example_incubation_period + reporting_delay),
-      stan = stan_opts(method = "vb"), # vb used for speed
-      forecast = forecast_opts(horizon = 7),
-      horizon = horizon
-    )
-  ))
-  # extract forecasts for testing
-  forecast_dt <- out$estimates$summarised[
-    variable == "reported_cases"
-  ][
-    type == "forecast"
-  ]
-  expect_true(out$estimates$args$horizon == horizon)
-  expect_true(nrow(forecast_dt) == horizon)
-})
