@@ -28,7 +28,8 @@ test_that("estimate_truncation can return values from simulated data with the
     est <- estimate_truncation(example_truncated,
       verbose = FALSE, chains = 2, iter = 1000, warmup = 250,
       stan = stan_opts(backend = "cmdstanr")
-  ))))
+    )
+  )))
   expect_equal(
     names(est),
     c("dist", "obs", "last_obs", "cmf", "data", "fit")
@@ -45,10 +46,10 @@ test_that("estimate_truncation works with filter_leading_zeros set", {
   # earlier dataset is corrected to be the same as the final dataset.
   modified_data <- data.table::copy(example_truncated)
   modified_data[[1]][1:3, confirm := 0]
+  modified_data <- lapply(modified_data, filter_leading_zeros)
   modified_data_fit <- estimate_truncation(
     modified_data,
-    verbose = FALSE, chains = 2, iter = 1000, warmup = 250,
-    filter_leading_zeros = TRUE
+    verbose = FALSE, chains = 2, iter = 1000, warmup = 250
   )
   # fit model to original dataset
   original_data_fit <- estimate_truncation(
@@ -76,9 +77,9 @@ test_that("estimate_truncation works with zero_threshold set", {
   # but with filter_leading_zeros = TRUE
   modified_data <- example_truncated
   modified_data <- purrr::map(modified_data, function(x) x[sample(1:10, 6), confirm := 0])
+  modified_data <- lapply(modified_data, apply_zero_threshold, threshold = 1)
   out <- estimate_truncation(modified_data,
-                             verbose = FALSE, chains = 2, iter = 1000, warmup = 250,
-                             zero_threshold = 1
+    verbose = FALSE, chains = 2, iter = 1000, warmup = 250
   )
   expect_named(out, c("dist", "obs", "last_obs", "cmf", "data", "fit"))
   expect_s3_class(out$dist, "dist_spec")
